==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/OktaSignOnPolicyRuleConditions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IdentityProviderPolicyRuleCondition;
import com.okta.sdk.resource.model.PolicyNetworkCondition;
import com.okta.sdk.resource.model.PolicyPeopleCondition;
import com.okta.sdk.resource.model.PolicyRuleAuthContextCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OktaSignOnPolicyRuleConditions
 */
@JsonPropertyOrder({ OktaSignOnPolicyRuleConditions.JSON_PROPERTY_AUTH_CONTEXT,
        OktaSignOnPolicyRuleConditions.JSON_PROPERTY_NETWORK, OktaSignOnPolicyRuleConditions.JSON_PROPERTY_PEOPLE,
        OktaSignOnPolicyRuleConditions.JSON_PROPERTY_IDENTITY_PROVIDER })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OktaSignOnPolicyRuleConditions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AUTH_CONTEXT = "authContext";
    private PolicyRuleAuthContextCondition authContext;

    public static final String JSON_PROPERTY_NETWORK = "network";
    private PolicyNetworkCondition network;

    public static final String JSON_PROPERTY_PEOPLE = "people";
    private PolicyPeopleCondition people;

    public static final String JSON_PROPERTY_IDENTITY_PROVIDER = "identityProvider";
    private IdentityProviderPolicyRuleCondition identityProvider;

    public OktaSignOnPolicyRuleConditions() {
    }

    public OktaSignOnPolicyRuleConditions authContext(PolicyRuleAuthContextCondition authContext) {

        this.authContext = authContext;
        return this;
    }

    /**
     * Get authContext
     *
     * @return authContext
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AUTH_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyRuleAuthContextCondition getAuthContext() {
        return authContext;
    }

    @JsonProperty(JSON_PROPERTY_AUTH_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAuthContext(PolicyRuleAuthContextCondition authContext) {
        this.authContext = authContext;
    }

    public OktaSignOnPolicyRuleConditions network(PolicyNetworkCondition network) {

        this.network = network;
        return this;
    }

    /**
     * Get network
     *
     * @return network
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyNetworkCondition getNetwork() {
        return network;
    }

    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNetwork(PolicyNetworkCondition network) {
        this.network = network;
    }

    public OktaSignOnPolicyRuleConditions people(PolicyPeopleCondition people) {

        this.people = people;
        return this;
    }

    /**
     * Get people
     *
     * @return people
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PEOPLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyPeopleCondition getPeople() {
        return people;
    }

    @JsonProperty(JSON_PROPERTY_PEOPLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPeople(PolicyPeopleCondition people) {
        this.people = people;
    }

    public OktaSignOnPolicyRuleConditions identityProvider(IdentityProviderPolicyRuleCondition identityProvider) {

        this.identityProvider = identityProvider;
        return this;
    }

    /**
     * Get identityProvider
     *
     * @return identityProvider
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_IDENTITY_PROVIDER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderPolicyRuleCondition getIdentityProvider() {
        return identityProvider;
    }

    @JsonProperty(JSON_PROPERTY_IDENTITY_PROVIDER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setIdentityProvider(IdentityProviderPolicyRuleCondition identityProvider) {
        this.identityProvider = identityProvider;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OktaSignOnPolicyRuleConditions oktaSignOnPolicyRuleConditions = (OktaSignOnPolicyRuleConditions) o;
        return Objects.equals(this.authContext, oktaSignOnPolicyRuleConditions.authContext)
                && Objects.equals(this.network, oktaSignOnPolicyRuleConditions.network)
                && Objects.equals(this.people, oktaSignOnPolicyRuleConditions.people)
                && Objects.equals(this.identityProvider, oktaSignOnPolicyRuleConditions.identityProvider);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(authContext, network, people, identityProvider);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OktaSignOnPolicyRuleConditions {\n");
        sb.append("    authContext: ").append(toIndentedString(authContext)).append("\n");
        sb.append("    network: ").append(toIndentedString(network)).append("\n");
        sb.append("    people: ").append(toIndentedString(people)).append("\n");
        sb.append("    identityProvider: ").append(toIndentedString(identityProvider)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/OktaSignOnPolicyRuleConditions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IdentityProviderPolicyRuleCondition;
import com.okta.sdk.resource.model.PolicyNetworkCondition;
import com.okta.sdk.resource.model.PolicyPeopleCondition;
import com.okta.sdk.resource.model.PolicyRuleAuthContextCondition;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OktaSignOnPolicyRuleConditions
 */
@JsonPropertyOrder({ OktaSignOnPolicyRuleConditions.JSON_PROPERTY_AUTH_CONTEXT,
        OktaSignOnPolicyRuleConditions.JSON_PROPERTY_NETWORK, OktaSignOnPolicyRuleConditions.JSON_PROPERTY_PEOPLE,
        OktaSignOnPolicyRuleConditions.JSON_PROPERTY_IDENTITY_PROVIDER })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class OktaSignOnPolicyRuleConditions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AUTH_CONTEXT = "authContext";
    private PolicyRuleAuthContextCondition authContext;

    public static final String JSON_PROPERTY_NETWORK = "network";
    private PolicyNetworkCondition network;

    public static final String JSON_PROPERTY_PEOPLE = "people";
    private PolicyPeopleCondition people;

    public static final String JSON_PROPERTY_IDENTITY_PROVIDER = "identityProvider";
    private IdentityProviderPolicyRuleCondition identityProvider;

    public OktaSignOnPolicyRuleConditions() {
    }

    public OktaSignOnPolicyRuleConditions authContext(PolicyRuleAuthContextCondition authContext) {

        this.authContext = authContext;
        return this;
    }

    /**
     * Get authContext
     *
     * @return authContext
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AUTH_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyRuleAuthContextCondition getAuthContext() {
        return authContext;
    }

    @JsonProperty(JSON_PROPERTY_AUTH_CONTEXT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAuthContext(PolicyRuleAuthContextCondition authContext) {
        this.authContext = authContext;
    }

    public OktaSignOnPolicyRuleConditions network(PolicyNetworkCondition network) {

        this.network = network;
        return this;
    }

    /**
     * Get network
     *
     * @return network
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyNetworkCondition getNetwork() {
        return network;
    }

    @JsonProperty(JSON_PROPERTY_NETWORK)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setNetwork(PolicyNetworkCondition network) {
        this.network = network;
    }

    public OktaSignOnPolicyRuleConditions people(PolicyPeopleCondition people) {

        this.people = people;
        return this;
    }

    /**
     * Get people
     *
     * @return people
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PEOPLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyPeopleCondition getPeople() {
        return people;
    }

    @JsonProperty(JSON_PROPERTY_PEOPLE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPeople(PolicyPeopleCondition people) {
        this.people = people;
    }

    public OktaSignOnPolicyRuleConditions identityProvider(IdentityProviderPolicyRuleCondition identityProvider) {

        this.identityProvider = identityProvider;
        return this;
    }

    /**
     * Get identityProvider
     *
     * @return identityProvider
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_IDENTITY_PROVIDER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdentityProviderPolicyRuleCondition getIdentityProvider() {
        return identityProvider;
    }

    @JsonProperty(JSON_PROPERTY_IDENTITY_PROVIDER)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setIdentityProvider(IdentityProviderPolicyRuleCondition identityProvider) {
        this.identityProvider = identityProvider;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OktaSignOnPolicyRuleConditions oktaSignOnPolicyRuleConditions = (OktaSignOnPolicyRuleConditions) o;
        return Objects.equals(this.authContext, oktaSignOnPolicyRuleConditions.authContext)
                && Objects.equals(this.network, oktaSignOnPolicyRuleConditions.network)
                && Objects.equals(this.people, oktaSignOnPolicyRuleConditions.people)
                && Objects.equals(this.identityProvider, oktaSignOnPolicyRuleConditions.identityProvider);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(authContext, network, people, identityProvider);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OktaSignOnPolicyRuleConditions {\n");
        sb.append("    authContext: ").append(toIndentedString(authContext)).append("\n");
        sb.append("    network: ").append(toIndentedString(network)).append("\n");
        sb.append("    people: ").append(toIndentedString(people)).append("\n");
        sb.append("    identityProvider: ").append(toIndentedString(identityProvider)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
